﻿using anbs_cp.Interfaces;

namespace anbs_cp.Classes;

/// <inheritdoc />
public sealed class ActionStateMessage: IActionStateMessage
{
    /// <inheritdoc />
    public bool IsCritical { get; set; }

    /// <inheritdoc />
    public object Object { get; set; }

    /// <inheritdoc />
    public string Message { get; set; }

    #region Конструкторы
    /// <summary>
    /// Конструктор по умолчанию
    /// </summary>
    // ReSharper disable once MemberCanBePrivate.Global
    public ActionStateMessage ()
    {
        IsCritical = true;
        Object = "Not Implemented";
        Message = "Not Implemented";
    }

    /// <summary>
    /// Конструктор с 2 параметрами
    /// </summary>
    /// <param name="message">Сообщение</param>
    /// <param name="isCritical">Критичность сообщения</param>
    public ActionStateMessage (string message, bool isCritical = true)
    {
        IsCritical = isCritical;
        Object = "";
        Message = message;
    }

    /// <summary>
    /// Конструктор с 3 параметрами
    /// </summary>
    /// <param name="eObject">Объект сообщения</param>
    /// <param name="message">Сообщение</param>
    /// <param name="isCritical">Критичность сообщения</param>
    public ActionStateMessage (object eObject, string message, bool isCritical = true)
    {
        IsCritical = isCritical;
        Object = eObject;
        Message = message;
    }
    #endregion

    #region Реализация интерфейса ISerializable
    /// <inheritdoc />
    public string Serialize () => new SysTextSerializer().Serialize(this);

    /// <inheritdoc />
    public void Deserialize (string json)
    {
        // Десериализую строку
        ActionStateMessage item = new SysTextSerializer().Deserialize<ActionStateMessage>(json) ?? new();

        // Передаю параметры
        IsCritical = item.IsCritical;
        Object = item.Object;
        Message = item.Message;
    }
    #endregion
}